package cn.iocoder.yudao.module.wealth.service.receiptInvoice;

import cn.iocoder.yudao.framework.common.pojo.PageResult;
import cn.iocoder.yudao.framework.mybatis.core.service.AbstractService;
import cn.iocoder.yudao.framework.mybatis.core.util.MyBatisUtils;
import cn.iocoder.yudao.framework.mybatis.core.vo.PageVO;
import cn.iocoder.yudao.module.wealth.convert.receiptInvoice.ReceiptInvoiceConvert;
import cn.iocoder.yudao.module.wealth.dal.dataobject.receiptInvoice.ReceiptInvoiceDO;
import cn.iocoder.yudao.module.wealth.dal.mysql.receiptInvoice.ReceiptInvoiceMapper;
import cn.iocoder.yudao.module.wealth.vo.receiptInvoice.*;
import com.baomidou.mybatisplus.core.metadata.IPage;
import org.springframework.stereotype.Service;
import org.springframework.validation.annotation.Validated;

import javax.annotation.Resource;
import java.util.Collection;
import java.util.List;

/**
 * 收款单开票信息 Service 实现类
 *
 * @author 系统管理员
 */
@Service
@Validated
public class ReceiptInvoiceServiceImpl extends AbstractService<ReceiptInvoiceMapper, ReceiptInvoiceDO> implements ReceiptInvoiceService {

    @Resource
    private ReceiptInvoiceMapper receiptInvoiceMapper;

    @Override
    public Long createReceiptInvoice(ReceiptInvoiceCreateReqVO createReqVO) {
        // 插入
        ReceiptInvoiceDO receiptInvoice = ReceiptInvoiceConvert.INSTANCE.convert(createReqVO);
        receiptInvoiceMapper.insert(receiptInvoice);
        // 返回
        return receiptInvoice.getId();
    }

    @Override
    public void updateReceiptInvoice(ReceiptInvoiceUpdateReqVO updateReqVO) {
        // 校验存在
        this.validateReceiptInvoiceExists(updateReqVO.getId());
        // 更新
        ReceiptInvoiceDO updateObj = ReceiptInvoiceConvert.INSTANCE.convert(updateReqVO);
        receiptInvoiceMapper.updateById(updateObj);
    }

    @Override
    public void deleteReceiptInvoice(Long id) {
        // 校验存在
        this.validateReceiptInvoiceExists(id);
        // 删除
        receiptInvoiceMapper.deleteById(id);
    }

    private void validateReceiptInvoiceExists(Long id) {
        if (receiptInvoiceMapper.selectById(id) == null) {
            //throw exception(RECEIPT_INVOICE_NOT_EXISTS);
        }
    }

    @Override
    public ReceiptInvoiceDetailVO getReceiptInvoiceDetail(Long id) {
        return receiptInvoiceMapper.getReceiptInvoiceDetail(id);
    }

    @Override
    public List<ReceiptInvoiceDO> getReceiptInvoiceList(Collection<Long> ids) {
        return receiptInvoiceMapper.selectBatchIds(ids);
    }

    @Override
    public PageResult<ReceiptInvoicePageBackVO> getReceiptInvoicePage(ReceiptInvoiceQueryVO query, PageVO page) {
        IPage<ReceiptInvoicePageBackVO> mpPage = MyBatisUtils.buildPage(page);
        receiptInvoiceMapper.getReceiptInvoicePage(mpPage, query);
        return PageResult.of(mpPage);
    }

    @Override
    public List<ReceiptInvoiceDO> getReceiptInvoiceList(ReceiptInvoiceQueryVO query) {
        return receiptInvoiceMapper.selectList(query);
    }
}
